#
# spec file for package perl-Email-Valid
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Email-Valid
Name:           perl-Email-Valid
Version:        1.204.0
Release:        1.3
# 1.204 -> normalize -> 1.204.0
%define cpan_version 1.204
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Check validity of Internet email addresses
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/R/RJ/RJBS/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Capture::Tiny)
BuildRequires:  perl(Mail::Address)
BuildRequires:  perl(Net::DNS)
BuildRequires:  perl(Net::Domain::TLD) >= 1.65
BuildRequires:  perl(Test::More) >= 0.96
Requires:       perl(Capture::Tiny)
Requires:       perl(Mail::Address)
Requires:       perl(Net::DNS)
Requires:       perl(Net::Domain::TLD) >= 1.65
Provides:       perl(Email::Valid) = %{version}
%undefine       __perllib_provides
%{perl_requires}

%description
This module determines whether an email address is well-formed, and
optionally, whether a mail host exists for the domain.

Please note that there is no way to determine whether an address is
deliverable without attempting delivery (for details, see at
http://perldoc.perl.org/perlfaq9.html#How-do-I-check-a-valid-mail-address).

%prep
%autosetup  -n %{cpan_name}-%{cpan_version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README
%license LICENSE

%changelog
* Fri Mar 22 2024 Tina Müller <tina.mueller@suse.com>
- Remove fix-test.patch, fixed upstream
* Sun Jan 21 2024 Tina Müller <timueller+perl@suse.de>
- updated to 1.204
  see /usr/share/doc/packages/perl-Email-Valid/Changes
  1.204     2024-01-20 16:40:53-05:00 America/New_York
  - replace IO::CaptureOutput with Capture::Tiny (thanks, Jim Keenan)
  - fix detection of null MX (thanks, Arne Johannessen)
* Wed Aug 24 2022 Tina Müller <tina.mueller@suse.com>
- Add fix-test.patch, see
  https://github.com/Perl-Email-Project/Email-Valid/issues/53
* Mon May 30 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.203
  see /usr/share/doc/packages/perl-Email-Valid/Changes
  1.203     2022-05-29 15:22:36-04:00 America/New_York
  - tiny packaging improvements
  - detect published null MX records (thanks, Gene Hightower)
* Wed Sep 28 2016 coolo@suse.com
- updated to 1.202
  see /usr/share/doc/packages/perl-Email-Valid/Changes
* Tue Sep 27 2016 coolo@suse.com
- updated to 1.202
  see /usr/share/doc/packages/perl-Email-Valid/Changes
  1.202     2016-09-25 21:48:09-04:00 America/New_York
  - avoid using a new Net::DNS feature, which should restore function
    with old versions of Net::DNS
* Sun Sep 25 2016 coolo@suse.com
- updated to 1.201
  see /usr/share/doc/packages/perl-Email-Valid/Changes
* Sat Sep 24 2016 coolo@suse.com
- updated to 1.201
  see /usr/share/doc/packages/perl-Email-Valid/Changes
  1.201     2016-09-22 19:21:01-04:00 America/New_York
  - mx check once again allows for A records; a future check may
    allow mx-only checks on purpose
* Mon Apr  4 2016 coolo@suse.com
- updated to 1.200
  see /usr/share/doc/packages/perl-Email-Valid/Changes
  1.200     2016-03-27 17:36:57-04:00 America/New_York
  - skip more tests when Net::Domain::TLD not available, as required
  1.199     2016-03-27 09:58:03-04:00 America/New_York
  - More "no MX found" fixes (thanks, Troy Morehouse)
  - treat restricted/reserved TLDs (invalid, test, example, localhost)
    as invalid (thanks, Steve Bertrand!)
  - Made first mention of various external modules be L<> linked.
  - Added link to RFC822 to SEE ALSO
  - Various typo and formatting fixes
* Thu Oct 29 2015 coolo@suse.com
- updated to 1.198
  see /usr/share/doc/packages/perl-Email-Valid/Changes
  1.198     2015-10-25 22:36:37-04:00 America/New_York
  - fix a typo that caused the MX check to die
* Sat Oct 17 2015 coolo@suse.com
- updated to 1.197
  see /usr/share/doc/packages/perl-Email-Valid/Changes
  1.197     2015-10-16 22:57:05-04:00 America/New_York
  - improve detection of "no MXes" (thanks, Troy Morehouse)
  - avoid some avoidable warnings (thanks, Svetlana)
* Tue Apr 14 2015 coolo@suse.com
- updated to 1.196
  see /usr/share/doc/packages/perl-Email-Valid/Changes
  1.196     2015-02-05 22:31:29-05:00 America/New_York
  - AOL "local rules" no longer enforced
  1.195     2014-09-01 08:38:58-04:00 America/New_York
  - handle domain part with MX but no A record (thanks, Karel Miko)
  1.194     2014-05-28 17:21:53-04:00 America/New_York
  - yhaoo.com grew an MX record; use something that won't
  1.193     2014-03-26 22:29:28-04:00 America/New_York
  - improve behavior on CNAME MX records
* Fri Oct  4 2013 coolo@suse.com
- updated to 1.192
    if Net::DNS is not available, do not test null mx validity
    update bugtracker, repo, etc.
    mxcheck fails when remote MX record is "."
    drop use of bytes.pm; any bug fixed by that should be fixed again
    properly
* Tue Jun  4 2013 coolo@suse.com
- updated to 0.190
    fix skip test count
    addresses in the form rjbs@[1.2.3.4], when allowed by allow_ip,
    are not failed for the tld check (reported by Marcel Grünauer)
    fix [rt.cpan.org #75736], in which 0@domain.com was considered
    invalid (thanks for the fix from Steve Bertrand)
* Mon Feb 27 2012 coolo@suse.com
- updated to 0.187
    addresses in the form rjbs@[1.2.3.4] are now (correctly) considered
    valid; this can be disabled with the -allow_ip option
    (this resolves RT#48398)
    check email address length and localpart length (thanks, Steve
    Bertrand!)
    use blessed($x) instead of wrapping an ->isa called in eval{}; this
    patch (thanks, Felipe Bergo!) was submitted to avoid problems with
    people who have global __DIE__ handlers, but was applied to just
    avoid the dumb eval{}; people with __DIE__ are otherwise on their
    own, here
* Fri Dec  2 2011 coolo@suse.com
- update to 0.185
    do not die in t/valid.t when testing for working DNS
    avoid a pointless warning
    check TLD validity before MX records
    reject addresses with non-ASCII characters
* Tue Apr 26 2011 coolo@opensuse.org
- updated to 0.184
    initialize Net::DNS resolver earlier
    (address RT #56828, thanks mschout @ github)
    reject addresses with any octets that are &128
    (address RT #50230, thanks Adriano Ferreira and Graham Barr)
* Mon Nov 29 2010 coolo@novell.com
- remove /var/adm/perl-modules
* Tue Oct  6 2009 jfunk@funktronics.ca
- Update to 0.182
  - skip DNS tests on machines with lying DNS
- 0.181     2009-03-23
  - explicitly require perl5 version 6
  - update some module metadata (Alexandr Ciornii)
  - remove hateful indirect method notation (Alexandr Ciornii)
- 0.180     2009-01-16
  - add repo location to metadata
- 0.179   Mon Nov 27 2006
  - bug 23657: fix domain label regex: thanks, Nobuaki ITO!
- 0.178   Sat Nov 25 2006
  - reduce cases in which IO::CaptureOutput is needed on Win32
    (bug 22062, thanks Alexandr Ciornii)
- 0.177   Sat Nov 25 2006
  - resolve bug 22710: make fqdn rule more strict: domains must be multiple
    valid domain labels, and domain labels must be [a-z0-9][-a-z0-9]*
    replace UNIVERSAL:: with eval{}-wrapping
- 0.176   Thu Jul 27 2006
  - further improve DNS stuff: try to make Net::DNS a prereq if we think
    we'll need it later
- 0.175   Sat Jun 24 2006
  - attempt to improve nslookup-location on Cygwin
  Sun Apr 12 2009 Christian Boltz
- some build and rpmlint fixes (unpackaged directories, unsafe RPM_BUILD_ROOT cleanup)
* Tue Jun 20 2006 James Oakley <jfunk@funktronics.ca> - 0.174-1
- Build under build service
* Fri Nov 11 2005 James Oakley <jfunk@funktronics.ca> - 0.15-ft.3
- Build for SL10
* Thu May 12 2005 James Oakley <jfunk@funktronics.ca> - 0.15-ft.2
- Build for SL93
* Fri Nov 19 2004 James Oakley <jfunk@funktronics.ca> - 0.15-ft.1
- Build for SL92
